@@ -38,7 +38,7 @@ class BaseModelWrapper(ABC):
     @abstractmethod
     def predict(self, data) -> Iterable:
         """Predicts data inputs."""
-        raise NotImplementedError
+        pass
 
     def predict_proba(self, data) -> Iterable:
         """Predicts probability of data inputs.
@@ -50,7 +50,7 @@ class BaseModelWrapper(ABC):
 
     @abstractmethod
     def load_model(self, model_path: str):
-        raise NotImplementedError
+        pass
 
     def get_feature_importance(self, input_data) -> Dict[str, float]:
         """Computes feature importance for each feature based on an input data.
@@ -94,7 +94,7 @@ class BaseSklearnModelWrapper(BaseModelWrapper):
     def __init__(self, params=pipeline_config.ModelWrapper()):
         super().__init__(params)
         self.save_model_name = "model_0"
-        self.model = factory.create(params.model_cls)(**self.model_params)
+        self.model = factory.create(params.sklearn_cls)(**self.model_params)
 
     def fit(self, data_loader: BaseDataLoader, model_dir: str):
         assert (
@@ -126,7 +126,7 @@ class BaseBoostingModelWrapper(BaseModelWrapper):
 
     @abstractmethod
     def _get_fit_params(self, train_data: Tuple, val_data: Tuple) -> Dict:
-        raise NotImplementedError
+        pass
 
     def fit(self, data_loader: BaseDataLoader, model_dir: str):
         assert (
@@ -151,7 +151,7 @@ class BaseLgbmModelWrapper(BaseBoostingModelWrapper):
 
     @abstractmethod
     def build_model(self):
-        raise NotImplementedError
+        pass
 
     def predict(self, data):
         return self.model.predict(data)
@@ -274,6 +274,14 @@ def write_model_wrapper_subclasses_to_file(
         f.writelines(lines)
 
 
+def initialize_model_wrapper(params: pipeline_config.ModelWrapper,):
+    """Initializes model wrapper from params."""
+    model_wrapper_cls = factory.create(params.cls_name)
+    if not issubclass(model_wrapper_cls, BaseModelWrapper):
+        raise ValueError(f"{model_wrapper_cls} is not a subclass of BaseModelWrapper")
+    return model_wrapper_cls(params)
+
+
 if __name__ == "__main__":
     # Show the subclasses of BaseModelWrapper
     write_model_wrapper_subclasses_to_file()
