@@ -9,7 +9,6 @@ from collections import Counter
 from pathlib import Path
 from typing import Any, Collection
 
-import git
 import GPUtil
 
 from tabml.utils.logger import logger
@@ -53,13 +52,6 @@ def check_uniqueness(items: Collection) -> None:
     assert not duplicates, f"There are duplicate objects in the list: {duplicates}."
 
 
-def get_git_root():
-    """Gets the root path of the current git repo."""
-    git_repo = git.Repo(Path.cwd(), search_parent_directories=True)
-    git_root = git_repo.git.rev_parse("--show-toplevel")
-    return git_root
-
-
 def show_feature_importance(data: typing.Dict[str, float]) -> None:
     """
     Shows feature importance in terminal.
